@@ -53,10 +53,19 @@ c             find max secondary energy.
 c              if very large x appears, discard it
 c              with some probabilty to adjust
 c              the x-distribution.
-          call rndc(u)
-          if(u  .lt. 
-     *         (  BigXRejCnst/(BigXRejCnst +
-     *         (xmax/(1.0-xmax))**BigXRejPw) ) )  goto 100
+c
+          if(xmax .gt. 0.4) then
+             call rndc(u)
+             if(u .lt.  (1. - (xmax-0.40)/0.6 )**2 ) then
+                goto 100
+             endif
+          else
+             goto 100
+          endif
+cc          call rndc(u)
+cc          if(u  .lt. 
+cc     *         (  BigXRejCnst/(BigXRejCnst +
+cc     *         (xmax/(1.0-xmax))**BigXRejPw) ) )  goto 100
        enddo
  100   continue
        end
