@@ -29,7 +29,7 @@ c             projectile and target information (both befor
 c             and after collision ) in different system.
 c
           integer k, icon, ntp, j, nevent, nuccharge, ntp0
-          real*8 x, y, eta, ek1
+          real*8 x, y, eta, ek1, ek
           real*8 xcms,  ek1cms
           integer NEVTS,NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,IEMU
           real*8 EPN
@@ -39,7 +39,7 @@ c
 
           real*8  energy
           real*8  gamma, beta
-
+          real*8  crossint
           real pt, ptx, pty, ke, teta, pz, pzcms, ptcms
           real  kecms, tetacms
 
@@ -48,9 +48,9 @@ c
           character*80  prefix
           character*16 uid
           character*16 input
-          integer ia, iz, leng, kgetenv
+          integer ia, iz, leng, kgetenv2
           logical lroots, cms, xbyp
-          integer dcy, i
+          integer dcy, i, kinc
 c////////////
           real*8  tgtA, tgtZ, xs
 c/////////////
@@ -62,7 +62,8 @@ c         OmegaBaryon Dmeson  eta      gzai   lambda    lambdac  pi0  sigma
      *              kpion, ksigma/
 
           call creadParam(5)
-
+          call cmkSeed(InitRN(1), InitRN)
+          call rnd1i(InitRN)     ! random number init.
 
           rest.p(1) = 0.
           rest.p(2) = 0.
@@ -98,17 +99,17 @@ c
           endif
 
           if(Trace .eq. 0) then
-c             write(*,
-c     *      '(a,l2, a,i2, a,i3, a,i2, a,g13.3, a,i3, a,i2,'//
-c     *      ' a,l2, a,l2, a, a, a)')
-c     *      '# "roots=',lroots, ' proj.code=',code, ' subcode=',
-c     *      subcode, ' chg=',charge, '  E=',energy,' target A=',
-c     *      ia, ' Z=',iz, ' cms=',cms, ' xbyp=',xbyp,
-c     *      ' intmodel=', IntModel(1:klena(IntModel)),
-c     *      '"' 
-c            write(*, '(a)') 
-c     * '# "X" "Xcms" "Pz" "Pzcms" "y" "eta" "pt" "code" '//
-c     * ' "subcd" "chg" "mult" "teta" "tetacms" "K.E" "K.Ecms" "ev#"'
+             write(0,
+     *      '(a,l2, a,i2, a,i3, a,i2, a,g13.3, a,i3, a,i2,'//
+     *      ' a,l2, a,l2, a, a, a)')
+     *      '# "roots=',lroots, ' proj.code=',code, ' subcode=',
+     *      subcode, ' chg=',charge, '  E=',energy,' target A=',
+     *      ia, ' Z=',iz, ' cms=',cms, ' xbyp=',xbyp,
+     *      ' intmodel=', IntModel(1:klena(IntModel)),
+     *      '"' 
+            write(0, '(a)') 
+     * '# "X" "Xcms" "Pz" "Pzcms" "y" "eta" "pt" "code" '//
+     * ' "subcd" "chg" "mult" "teta" "tetacms" "K.E" "K.Ecms" "ev#"'
 c           defalut trace.  fix the dirctor
          else
           if(TraceDir .eq. ' ') then
@@ -155,8 +156,7 @@ c             initialize. we are using as if from Comsos
              call cintModels('cosmos')
           else
              if(prefix .eq. ' ' ) then
-                NULL = char(0)
-                leng = kgetenv("EPICSTOP"//NULL, prefix)
+                leng = kgetenv2("EPICSTOP", prefix)
                 if(leng .eq. 0) then
                    call cerrorMsg('EPICSTOP is not given', 0)
                 endif
@@ -188,7 +188,7 @@ c              This is to form  Cmsp
 
           cmspsave = Cmsp
 
-          call rnd1i(InitRN)     ! random number init.
+
 c             fix model by seeing the proj. energy.
           call cfixModel(pj)
           compj = pj
@@ -198,7 +198,7 @@ c             fix model by seeing the proj. energy.
           else
              ek1 = pj2.fm.p(4) -  pj2.mass
           endif
-
+          ek = pj2.fm.p(4) -  pj2.mass
 
           call cbst1(1, cmspsave,  pj2, cmspj)
 	  if(xbyp) then
@@ -215,13 +215,22 @@ c             fix model by seeing the proj. energy.
           comtgcms = cmstg
 
 
-
           if(SeedFile .ne. ' ') then
              call copenfw(SeedFileDev, SeedFile, icon)
              if(icon .ne. 0) then
                 call cerrorMsg(' SeedFile open error' ,0)
              endif
           endif
+
+          write(0,*) ' ActiveModel =',ActiveMdl
+
+          if( ActiveMdl .eq. 'qgsjet2') then
+c               qgsjet xs must be called
+             call cxsecQGS(pj, ia, xs)
+          elseif(ActiveMdl .eq. 'incdpm3') then
+             call cccode2hcode(pj,  kinc)              
+             xs = crossint(kinc, ek)
+          endif
           k = 1
           do while(k .le.  nevent)
              if(SeedFile .ne. ' ') then
@@ -298,27 +307,13 @@ c                    transform to CMS.
                    tetacms = atan2( ptcms, sngl(a(j).fm.p(3)) ) *
      *               180./3.1415
                    kecms = a(j).fm.p(4)-a(j).mass
-c
-                   if( xcms .gt. 0. .and.
-     *                a(j).code .eq. 1) then
-                      if( a(j).fm.p(4) .gt. 80.) then
-c                      if(pt/a(j).fm.p(4)*14000.0 .lt. 11.) then
-                         write(*,*) sngl( a(j).fm.p(4)),
-c     *                      sngl(pt/a(j).fm.p(4)*14000.0),
-     *                      ptcms
-                      endif
-                   endif
-c                   write(*, *) a(j).code,  a(j).charge, sngl(x)
-c                   if(xcms .gt. 1.e-4) then
-c                      write(*, '(2i3, 2g12.3)')
-c     *                a(j).code, a(j).charge, sngl(xcms), sngl(x)
-c                   endif   
-c                   write(*, '(7g14.3, 3i3, i6, 2g16.6, 2g14.3, i8)' )
-c     *               sngl(x), sngl(xcms), pz, pzcms, sngl(y), 
-c     *               sngl(eta),  pt, 
-c     *               a(j).code, a(j).subcode, a(j).charge,
-c     *               ntp, teta, tetacms,
-c     *               ke, kecms, k
+
+                   write(*, '(7g14.4, 3i3, i6, 2g16.6, 2g14.4, i8)' )
+     *               sngl(x), sngl(xcms), pz, pzcms, sngl(y), 
+     *               sngl(eta),  pt, 
+     *               a(j).code, a(j).subcode, a(j).charge,
+     *               ntp, teta, tetacms,
+     *               ke, kecms, k
                 else
                    call cvisualizeTrack(a(j), 0, ext*0.35)
                 endif
@@ -337,6 +332,8 @@ c     *               ke, kecms, k
      *      ' You can also use "slide" command in Util', 1) 
           endif
        end
+
+
       subroutine cvisualizeTrack(pp, inout, ext)
       implicit none
 #include "Zptcl.h"
