@@ -25,12 +25,14 @@ c
       if(out .eq. 5) then
          write(*,'("# -----------------# of Component defined=",
      *           i2,"----------------------")')  prm.no_of_comps
-         write(*,'("# Seq.# Code  Comp.  E_ Unit  E_type Diff/Integ",
-     *        "  Emin    Emax   # of seg.  inte.flux")')
+         write(*,
+     *     '("# Seq.#  Code  Comp.    E_ Unit  E_type Diff/Integ",
+     *     "  Emin    Emax   # of seg.  inte.flux")')
       else
          write(out,'("# -----------------# of Component defined=",
      *           i2,"----------------------")')  prm.no_of_comps
-         write(out,'("# Seq.# Code  Comp.  E_ Unit  E_type Diff/Integ",
+         write(out,
+     *     '("# Seq.#  Code  Comp.    E_ Unit  E_type Diff/Integ",
      *        "  Emin    Emax   # of seg. inte.flux ")')
       endif
       do i = 1, prm.no_of_comps
@@ -46,13 +48,13 @@ c
       integer out
 c
       if(out .eq. 5) then
-         write(*, '("#",i4,i6, 3x, a6, a6, a9, a8, 5x, 2g9.3,i4,
+         write(*, '("#",i4,i6, 2x, a10, a7, a9, a8, 5x, 2g9.3,i4,
      *   1x, g9.3)')
      *   each.label, each.code, each.symb, each.eunit, each.etype,
      *   each.diff_or_inte,
      *   each.emin, each.emax, each.no_of_seg, each.inte_value
       else
-         write(out, '("#",i4,i6, 3x, a6, a6, a9, a8, 5x, 2g9.3,i4,
+         write(out, '("#",i4,i6, 2x, a10, a7, a9, a8, 5x, 2g9.3,i4,
      *    1x,  g9.3)')
      *   each.label, each.code, each.symb, each.eunit, each.etype,
      *   each.diff_or_inte,
