@@ -33,13 +33,7 @@ c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
       integer ica, ka, subcode, kinc, ia
       logical useInt2
       character*70 msg
-      logical first/.true./
-      save first
-      
-      if( first ) then
-         call cixsec
-         first = .false.
-      endif
+
 
       et = TrackBefMove.p.fm.p(4)
       mass = TrackBefMove.p.mass
